@@ -1,6 +1,7 @@
 """Defines the main FileTree object, which will be the main point of interaction
 """
 from collections import defaultdict
+import warnings
 import xarray
 from .template import Template, Placeholders
 from typing import Generator, Optional, Dict, Any, Sequence, Union
@@ -90,6 +91,12 @@ class FileTree:
             FileTree: tree matching the definition in the file
         """
         from . import parse_tree
+        if 'directory' in placeholders:
+            warnings.warn(
+                f"Setting the 'directory' placeholder to {placeholders['directory']}. " +
+                "This differs from the behaviour of the old filetree in fslpy, which used the `directory` keyword to set the top-level directory. " +
+                "If you want to do that, please use the new `top_level` keyword instead of `directory`."
+                )
         for filename in (name, str(name) + '.tree'):
             if Path(filename).is_file():
                 with open(filename, 'r') as f:
@@ -232,6 +239,8 @@ class FileTree:
                 Defaults to top-level directory of the main tree. 
                 Can be set to None for an independent tree.
         """
+        if isinstance(precursor, str):
+            precursor = [precursor]
         for name in precursor:
             if name is None:
                 add_string = ""
@@ -261,11 +270,6 @@ class FileTree:
                     been_assigned[old_template] = key
                     del to_assign[key]
 
-            if isinstance(key, Path):
-                key = str(key)
-            if isinstance(key, str):
-                key = [key]
-
             for key, template in assigned.items():
                 if key == '' and name is None:
                     continue
@@ -344,7 +348,7 @@ class FileTree:
         """
         path = self.get_template(key).format_single(self.placeholders)
         if make_dir:
-            path.parent.mkdir(parents=True, exist_ok=True)
+            Path(path).parent.mkdir(parents=True, exist_ok=True)
         if self.return_path:
             return Path(path)
         return path
@@ -378,7 +382,7 @@ class FileTree:
             if make_dir:
                 for path in paths.data.flat:
                     if path is not None:
-                        path.parent.mkdir(parents=True, exists_ok=True)
+                        Path(path).parent.mkdir(parents=True, exists_ok=True)
             if self.return_path:
                 return xarray.apply_ufunc(lambda p: None if p == "" else Path(p), paths, vectorize=True)
             return paths
