@@ -79,7 +79,22 @@ class Placeholders(MutableMapping):
                 if k in self.mapping:
                     del self.mapping[k]
         elif key in self.linkages:
-            raise ValueError(f"Can not overwrite placeholder {key} as it is linked to: {self.linkages[key]}")
+            old_values = self.mapping[self.linkages[key]]
+            if is_singular(value):
+                if value in old_values[key]:
+                    self.unlink(*old_values.keys())
+                    idx = old_values[key].index(value)
+                    for skey in old_values:
+                        self.mapping[skey] = old_values[skey][idx]
+                else:
+                    raise ValueError(f"Can not overwrite placeholder {key} with new values as it is linked to: {self.linkages[key]}")
+            else:
+                if all(v in old_values[key] for v in value):
+                    idx = [old_values[key].index(v) for v in value]
+                    for skey in old_values:
+                        old_values[skey] = tuple(old_values[skey][i] for i in idx)
+                else:
+                    raise ValueError(f"Can not overwrite placeholder {key} with new values as it is linked to: {self.linkages[key]}")
         else:
             self.mapping[key] = value
 
